==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredCredentialEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapRequiredCredentialEntityDelegate implements org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> delegateProvider;
    public MapRequiredCredentialEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE, type).setType(type);
    }
    @Override public String getFormLabel() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL).getFormLabel();
    }
    @Override public void setFormLabel(String formLabel) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL, formLabel).setFormLabel(formLabel);
    }
    @Override public Boolean isSecret() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET).isSecret();
    }
    @Override public void setSecret(Boolean secret) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET, secret).setSecret(secret);
    }
    @Override public Boolean isInput() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT).isInput();
    }
    @Override public void setInput(Boolean input) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT, input).setInput(input);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredCredentialEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapRequiredCredentialEntityDelegate implements org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> delegateProvider;
    public MapRequiredCredentialEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapRequiredCredentialEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.TYPE, type).setType(type);
    }
    @Override public String getFormLabel() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL).getFormLabel();
    }
    @Override public void setFormLabel(String formLabel) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.FORM_LABEL, formLabel).setFormLabel(formLabel);
    }
    @Override public Boolean isSecret() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET).isSecret();
    }
    @Override public void setSecret(Boolean secret) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.SECRET, secret).setSecret(secret);
    }
    @Override public Boolean isInput() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT).isInput();
    }
    @Override public void setInput(Boolean input) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapRequiredCredentialEntityFields.INPUT, input).setInput(input);
    }
}
